pub struct ZxdgImporterV1 { /* private fields */ }Expand description
interface for importing surfaces
A global interface used for importing surfaces exported by xdg_exporter. With this interface, a client can create a reference to a surface of another client.
See also the Request enum for this interface.